@@ -1,39 +1,17 @@
-use super::MethodPayableMetadata;
+use super::{EndpointLocationMetadata, EndpointMutabilityMetadata, MethodPayableMetadata};
 
 #[derive(Clone, Debug)]
 pub struct InitMetadata {
     pub payable: MethodPayableMetadata,
 }
 
-#[derive(Debug, Clone)]
-pub enum EndpointMutabilityMetadata {
-    Mutable,
-    Readonly,
-    _Pure,
-}
-
-impl EndpointMutabilityMetadata {
-    pub fn to_tokens(&self) -> proc_macro2::TokenStream {
-        match self {
-            EndpointMutabilityMetadata::Mutable => {
-                quote! { elrond_wasm::abi::EndpointMutabilityAbi::Mutable }
-            },
-            EndpointMutabilityMetadata::Readonly => {
-                quote! { elrond_wasm::abi::EndpointMutabilityAbi::Readonly }
-            },
-            EndpointMutabilityMetadata::_Pure => {
-                quote! { elrond_wasm::abi::EndpointMutabilityAbi::Pure }
-            },
-        }
-    }
-}
-
 #[derive(Clone, Debug)]
 pub struct EndpointMetadata {
     pub public_name: syn::Ident,
     pub payable: MethodPayableMetadata,
     pub only_owner: bool,
     pub mutability: EndpointMutabilityMetadata,
+    pub location: EndpointLocationMetadata,
 }
 
 #[derive(Clone, Debug)]
