@@ -1,5 +1,4 @@
-use syn::punctuated::Punctuated;
-use syn::token::Colon2;
+use syn::{punctuated::Punctuated, token::Colon2};
 
 /// Path to a Rust module containing a contract module.
 pub type ModulePath = Punctuated<syn::PathSegment, Colon2>;
