@@ -5,6 +5,8 @@ mod endpoint_attr;
 mod event_attr;
 mod payable_attr;
 mod storage_attr;
+mod trait_argument_prop;
+mod trait_prop_names;
 mod util;
 
 pub use argument_attr::*;
@@ -13,3 +15,4 @@ pub use endpoint_attr::*;
 pub use event_attr::*;
 pub use payable_attr::*;
 pub use storage_attr::*;
+pub use trait_argument_prop::*;
